import { Component, OnInit, Input, Inject } from '@angular/core';
import { Target } from '../../../target/model';
import { MAT_DIALOG_DATA } from '@angular/material';
import { Infra } from '../../../infra/model';
import { MetaCrawler } from '../../../meta/crawler/model/MetaCrawler';
import { MetaSensorDisplayItem } from '../../../meta/sensor-display-item/model/MetaSensorDisplayItem';


@Component({
  selector: 'of-sensor-setting',
  templateUrl: './setting.component.html',
  styleUrls: ['./setting.component.scss']
})
export class SettingComponent implements OnInit {

  selectedTarget: Target = null;
  selectedCrawler: MetaCrawler = null;
  selectedSensorDisplayItems: Set<MetaSensorDisplayItem> = null;
  step = 1;

  constructor(
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
    if (data !== null) {
      this.selectedTarget = data.infra.target;
    }
  }

  ngOnInit() {
  }

  onNext() {
    const valid = this.validateSelection();
    if (valid !== null) {
      alert(valid);
      return;
    }
    this.step += 1;
  }

  validateSelection() {
    let message = null;
    if (this.selectedTarget === null) {
      message = 'Target is not selected.';
    }
    if (this.selectedCrawler === null) {
      message = 'Crawler is not selected.';
    }
    if (this.selectedSensorDisplayItems === null || this.selectedSensorDisplayItems.size === 0) {
      message = 'SensorItem is not selected.';
    }
    return message;
  }

  onPrev() {
    this.step -= 1;
  }

  onDone() {
    console.log('finished');
  }

  handleTargetSelection(t: Target) {
    this.selectedTarget = t;
  }
  handleCrawlerSelection(c: MetaCrawler) {
    this.selectedCrawler = c;
  }
  handleItemSelection(itemSet: Set<MetaSensorDisplayItem>) {
    this.selectedSensorDisplayItems = itemSet;
  }
}
